<?php
/**
 *
 * @category        pagemodule
 * @package         google reviews
 * @author          Ruud Eisinga - dev4me
 * @link			https://dev4me.com/modules-snippets/
 * @license         https://www.gnu.org/licenses/gpl.html
 * @platform        WebsiteBaker 2.10.x
 * @platform        WBCE 1.3.x
 * @version         1.0
 * @lastmodified    Februari 6, 2024
 *
 */
 
 
function __showReviews($row, $sid) {
	global $database, $table_mod, $table_data;
	$template = file_get_contents(__DIR__.'/card.htt');
	$extra = $row['show_only_with_text'] ? "AND `text` != '' ":'';
	$query = "SELECT * FROM `$table_data` 
		WHERE `section_id`='$sid' 
		AND `visible`='1' 
		AND `rating`>='{$row['show_min_stars']}' 
		$extra
		ORDER BY `time` DESC LIMIT {$row['show_max_reviews']}";
		
	if($res = $database->query($query)) {
		echo '<div class="reviews">';
		if($row['title']) echo '<h2 class="review-title">'.$row['title'].'</h2>';
		echo '<div id="mySwipe" class="swipe">';
		echo '<div class="swipe-wrap">';
		while($rec = $res->fetchRow()) {
			$stars = '';
			for ($i=1; $i <= $rec['rating']; ++$i) $stars .= '<span class="on">★</span>';
			for ($i=1; $i <= (5 - floor($rec['rating'])); ++$i) $stars .= '<span class="off">★</span>';
			$var = $value = array();
			$var[] = '{DATE}'; $value[] = date(DATE_FORMAT,$rec['time']+TIMEZONE);
			$var[] = '{AUTHOR}'; $value[] = $rec['author'];
			$var[] = '{AVATAR}'; $value[] = $rec['avatar'];
			$var[] = '{AVATARURL}'; $value[] = $rec['avatar_url'];
			$var[] = '{REVIEW}'; $value[] = nl2br($rec['text']);
			$var[] = '{HIDE-REVIEW}'; $value[] = $rec['text'] ? '':' style="display:none"';
			$var[] = '{STARS}'; $value[] = $stars;
			echo str_ireplace($var,$value,$template);
		}
		echo '</div>';
		echo '</div>';
		echo '</div>';
		echo '<script>';
		echo "var element = document.getElementById('mySwipe');";
		echo "window.mySwipe = new Swipe(element,{
		  auto: 5000,
		  speed: 1000,
		  draggable: true,
		  autoRestart: true,
		  disableScroll: true,
		  stopPropagation: true,
		});";
		echo '</script>';
	}
}


function __updateReviews($row, $sid) {
	global $database, $table_mod, $table_data;
	$places = explode(',',$row['google_place_id']);
	foreach($places as $place_id) {
		$url = 'https://maps.googleapis.com/maps/api/place/details/json?place_id='.$place_id.'&key='.$row['google_key'].'&language='.strtolower(LANGUAGE);
		$result = __fetch($url);
		$data  = json_decode($result, true);
		if(!isset($data['result']['reviews'])) {
			continue;
		}
		
		$s = array();
		$s['section_id'] = $sid;
		$s['rating'] = $data['result']['rating'];
		$s['name'] = $data['result']['name'];
		$s['last'] = time();
		__updateRecord($table_mod,'section_id',$s);
		$reviews = $data['result']['reviews'];
		if (!empty($reviews)) {		
			foreach ($reviews as $key => $review) {
				
				$image = __fetch($review['profile_photo_url']);
				$avatar = 'data:image/jpg;base64,'.base64_encode($image);
				$data=array();
				$data['text'] = $review['text'];
				$data['rating'] = $review['rating'];
				$data['author'] = $review['author_name'];
				$data['author_url'] = $review['author_url'];
				$data['avatar'] = $avatar;
				$data['avatar_url'] = $review['profile_photo_url'];
				$data['language'] = $review['language'];
				$data['name'] = $s['name'];
				$data['time'] = $review['time'];
				$data['timestamp'] = time();
				$data['section_id'] = $sid;
				__updateRecord($table_data,'time',$data);
			}
		}
	}
}

function __fetch($url) {
	$result = '';
	if (function_exists('curl_version')) {
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_USERAGENT, 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Safari/537.36');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		$result = curl_exec($ch);
		curl_close($ch);
	} else {
		$arrContextOptions=array(
			'ssl' => array(
			  'verify_peer' => false,
			  'verify_peer_name' => false,
			),
			'http' => array(
			  'method' => 'GET',
			  "User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Safari/537.36\r\n"
			)
		);  
		$result = file_get_contents($url, false, stream_context_create($arrContextOptions));
	}
	return $result;
}

function __updateRecord ( $table, $id_field, $data ) {
	global $database;
	$set = '';
	$val = '';
	$exist = 0;
	if (isset($data[$id_field]) && $data[$id_field]) {
		$exist = $database->get_one("SELECT count(`$id_field`) FROM `$table` WHERE `$id_field`='".$data[$id_field]."' LIMIT 1");
	}
	if (!$exist) {
		foreach ( $data as $key => $value ) {
			$value = $database->escapeString($value);
			$set .= $set ? ',`'.$key.'`':'`'.$key.'`';
			$val .= $val ? ",'$value'" : "'$value'";
		}
		$query = "INSERT INTO ".$table." ($set) VALUES ($val)";
		//echo '<br>'.$query.'<br>';
		$database->query($query);
		return $database->get_one("SELECT LAST_INSERT_ID()");
	} else {
		$id = $data[$id_field];
		foreach ( $data as $key => $value ) {
			if ($key != $id_field) {
				$value = $database->escapeString($value);
				$set .= $set ? ',':'';
				$set .= "`$key`='$value'";
			}
		}
		$query = "UPDATE ".$table." SET $set where `$id_field` = '$id'";
		//echo '<br>'.$query.'<br>';
		$database->query($query);
		return $id;
	}
}

function __select($name = null, $current = '', $values = array()) {
	if(!$name) return '';
	
	$rval = '<select class="review-selector" name="'.$name.'">';
	foreach($values as $key => $value) {
		$s = $current == $key ? 'selected':'';
		$rval .= '<option '.$s.' value="'.$key.'">'.$value.'</option>';
	}
	$rval .= '</select>';
	return $rval;
}	
	